import os

from loguru import logger
from dyndebug import Debug
from typing import Callable, Any
from dotmap import DotMap
from capturejob.service.fileservice import FileService
from datetime import datetime

def checkPrerequsites(variable):
    if os.getenv(variable) is None:
        return True
    return False


def CaptureJob():
    debug = Debug('capturejob')

    issues = list(
        filter(
            checkPrerequsites,
            ["CAPTURE_CONNECTION_STRING","CAPTURE_CONTAINER_NAME","TASK_ID"],
        )
    )
    if len(issues) > 0:
        raise Exception(f"Missing environment variables {issues}")

    config = DotMap({
        "connectionString": os.environ.get("CAPTURE_CONNECTION_STRING"),
        "containerName": os.environ.get("CAPTURE_CONTAINER_NAME"),
    })

    print(config.containerName)
    fileservice =FileService(config)

    job = os.environ.get("TASK_ID")

    now = datetime.now() 
    date_time = now.strftime("%Y%m%d_%H%M%S")    

    cwd = os.getcwd()
    
    folder = f"{date_time}_{job}"
    fileservice.upload(os.path.join(cwd,"log.txt"),folder,"log.txt")    
 


# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['capturejob', 'capturejob.service']

package_data = \
{'': ['*']}

install_requires = \
['azure-storage-blob>=12.9.0,<13.0.0',
 'dotmap>=1.3.26,<2.0.0',
 'dyndebug>=0.2.0,<0.3.0',
 'loguru>=0.5.3,<0.6.0',
 'python-dotenv>=0.19.2,<0.20.0']

entry_points = \
{'console_scripts': ['start = capturejob.main:main', 'test = pytest:main']}

setup_kwargs = {
    'name': 'capturejob',
    'version': '0.2.0',
    'description': 'A library to capture job outputs to persistent storage',
    'long_description': '# CaptureJob\n\nThis library provides the ability to copy stdout and stderr files to cloud storage.\n\n## Usage\n\nProgrammatically it is used like this:\n```\nfrom capturejob import CaptureJob\n\nCaptureJob()\n```\n\nbut mainly its intended to be used in a dockerfile command script followng execution of a command script.\n\n```\necho "Running batch"\n\ncd /work && poetry run python src/etl_noop/batchrun.py\n\nJOB="...\nCAPTURE_CONNECTION_STRING="..." \nCAPTURE_CONTAINER_NAME="..."\npoetry run python -m capturejob \n\necho "Done"\n```\n\n## Configuration\n\nThe following environment variables need to be set\n\n- JOB:  A name of the job which is used in the storage folder name created\n- CAPTURE_CONNECTION_STRING: Azure connection string\n- CAPTURE_CONTAINER_NAME: Azure container name\n',
    'author': 'aurecon',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import io
import json
import os
import pdb
from collections import namedtuple

from azure.storage.blob import (BlobClient, BlobServiceClient, ContainerClient,
                                __version__)
from dyndebug import Debug
from loguru import logger


def FileService(config):

    fileService = namedtuple(
        "FileService", "upload"
    )

    debug = Debug("fileservice")
    
    def upload(fullpath:str, folder:str,filename:str):

        debug(config)
        remotepath = f"{folder}/{filename}"
        debug(f"Pushing {fullpath} to storage {config.containerName}:{remotepath}")
        # Create a blob client using the local file name as the name for the blob
        
        blob_service_client = BlobServiceClient.from_connection_string(
            config.connectionString
        )
        blob_client = blob_service_client.get_blob_client(
            container=config.containerName, blob=remotepath
        )

        debug("\nUploading to Azure Storage as blob:\n\t" + filename)

        # Upload the created file    
        
        with open(fullpath, "rb") as data:
            blob_client.upload_blob(data, overwrite=True)            

    
    return fileService(upload)
